from collections import UserDict
from datetime import date, datetime

import re
import pickle
import sys

from classes.field import Field
from classes.name import Name
from classes.birthday import Birthday
from classes.phone import Phone
from classes.email import Email
from classes.address import Address
from classes.record import Record
from classes.addressbook import AddressBook

from classes.note import Note
from classes.notes import Notes
from classes.functions import make_menu 

from sort import sort

from classes.settings import filename, PAG, notes_filename


wellcome_message = f"Please enter your command:  "
hello_message = "How can I help you?"
good_bye_message = "Good bye!"
bad_command = "Incorrect command!"
add = "Please write name, address, phone, email, date of birth"
change = "Write the name of the contact you want to change"
delete = "Write the name of contact you want to delete"
find = "Write the name or phone number of the contact you want to find"
help_string = """For working with me, please, input one of next command:
"hello" - I print "How can I help you?"
"show all" - I print all recorded phone numbers
"find" - I find record by name or phone
"good bye", "close" or "exit" - I stop working
"help" - I print this text
"add" - I add name, phone, email, date of birth, address
"change" - I can change the data
"delete" - I can delete contact"""
  

def edit_record(book):

    contact_name = input("Please enter the name of the contact what you want to change ")
    find_record = book.find(contact_name)
    if find_record is None:
        print("Contact name not found ")
    else:
        edit_record_menu = '''Edit Record menu: Please, input your choice:
1. Edit Name
2. Edit Phone
3. Edit Birthday
4. Edit Email
5. Edit Address
6. Save and Exit
7. Exit''' 
        edit_swither = True
        while  edit_swither:
            print(find_record)
            print(edit_record_menu)
            choice = input()
            if choice == '7':
                break
            elif choice == "1":
                new_name = input("Please enter new name ")
                find_record.edit_name(new_name)
                if new_name != contact_name:
                    book.add_record(find_record)
                    book.delete(contact_name)
            elif choice == "2":
                print("Please enter new phone ")
                new_phone = input("Please enter new phone ")
                find_record.add_phone(new_phone)
            elif choice == "3":
                new_birthday = input("Please enter new birthday ")
                find_record.edit_birthday(new_birthday)
            elif choice == "4":
                new_email = input("Please enter new email ")
                find_record.edit_email(new_email)
            elif choice == "5":
                new_address = input("Please enter new address ")
                find_record.edit_address(new_address) 
            elif choice == "6":
                book.write_contacts_to_file(filename)
                break


def appruve_record(book, new_record):
    print(new_record)
    print('''What You will do with this record?
1 - Save
2 - Edit
3 - Delete''')
    choise = input()
    if choise == "1":
        book.write_contacts_to_file(filename)
        print(new_record)
        print("Record saved successful")
    elif choise == "2":
        pass

    elif choise == "3":
        book.delete(new_record)


def main():
    
    if len(sys.argv) > 1:
        sort(sys.argv[1])
        quit()

    else:

        notes = Notes()
        notes = notes.load_from_file(notes_filename)
        
        main_menu = '''Main Menu: Please, input your choice:
1 - About Bot Helper
2 - Hello, User!
3 - Use Records
4 - Use Notes
5 - Exit
'''

        while True:

            choice1 = input(main_menu)

            if choice1 == "1":
                pass
                #about bot
            elif choice1 == "2":
                #hello user
                pass

            elif choice1 == "3":
                switcher = True

                while switcher:

                    book = AddressBook()
                    book = AddressBook.read_contacts_from_file(filename)
                    record_menu = '''Record menu: Please, input your choice:
1. Show all Records
2. Find Records
3. Show Record whith birthday in N days
4. Add Record
5. Edit Record
6. Delete record
7. Save AdressBook and Exit
8. Exit to prewius menu
'''
                    choice2 = input(record_menu)
                    if choice2 == "1":
                        book.iterator()
                    elif choice2 == "2":
                        find_string = input("Please input Name of record, which you want find: ")
                        find_result = AddressBook()
                        find_result = book.find_record(find_string)
                        if find_result:
                            book.find_record(find_string).iterator_simple()
                        else:
                            print(f"I can`t find any matches with '{find_string}'")
                    
                    
                    elif choice2 == "3":
                        days_to_serch = input("Please, input number of days to search")
                        book.find_birthdays(days_to_serch).iterator()
    
                    
                    
                    elif choice2 == "4":
                        name = input("Please enter the name ")
                        phone = input("Please enter the phone ")
                        email = input("Please enter the email ")
                        address = input("Please enter the address ")
                        birthday = input("Please enter the date of birth ")
                        new_record = Record(name)
                        new_record.add_phone(phone)
                        new_record.add_email(email)
                        new_record.add_address(address)
                        new_record.add_birthday(birthday)
                        book.add_record(new_record)
                        print('Contact added')
                        appruve_record(book, new_record)
                    elif choice2 == "5":
                        edit_record(book)
                    elif choice2 == "6":
                        contact_name = input("Please enter contact name you need to delete ")
                        book.delete(contact_name)            
                    elif choice2 == "7":
                        book.write_contacts_to_file(filename)
                        quit()      
                    elif choice2 == "8":
                        switcher = False


            elif choice1 == "4":
                make_menu(notes)

            elif choice1 == "5":
                break


if __name__ == '__main__':
    main()



import os
import re
import sys
import shutil


def sort(path):
        
    def normalize(name: str) -> str:
        name, *extension = name.split('.')
        new_name = name.translate(TRANS)
        new_name = re.sub(r'\W', '_', new_name)
        return f"{new_name}.{'.'.join(extension)}"

    def getExtension(name: str) -> str:
        name, extension = name.split('.')
        return extension

    def makeDir(name):
        if not os.path.exists(name):
            os.mkdir(name)

    def walkSortDir(path, level=1, list_of_use_extensions=[], list_other_extensions=[]):
        for i in os.listdir(path):
            if os.path.isdir(path + separator + i):
                walkSortDir(path + separator + i, level + 1,
                            list_of_use_extensions, list_other_extensions)
            if not os.path.isdir(path + separator + i):
                extension = getExtension(i)
                unsorted = True
                for type in LIST_OF_TYPES:
                    if extension in type:
                        makeDir(os.path.abspath(PATH) + separator + type[0])
                        os.replace(os.path.abspath(path + separator + i),
                                os.path.abspath(PATH + separator + type[0] + separator + (normalize(i))))
                        unsorted = False
                        list_of_use_extensions.append(extension)
                if unsorted:
                    makeDir(os.path.abspath(PATH) + separator + OTHERS)
                    os.replace(os.path.abspath(
                        path + separator + i), os.path.abspath(PATH + separator + OTHERS + separator + (normalize(i))))
                    list_other_extensions.append(extension)
        return (set(list_of_use_extensions), set(list_other_extensions))

    def removeSortedDir(name):
        for i in os.listdir(name):
            if os.path.isdir(name + separator + i) and i not in LIST_OF_DIRS:
                shutil.rmtree(name + separator + i)

    def unpackSortedArchives(arc_path):
        if os.path.exists(arc_path + separator + ARCHIVES[0]):
            for i in os.listdir(arc_path + separator + ARCHIVES[0]):
                if not os.path.isdir(arc_path + separator + ARCHIVES[0] + separator + i):
                    try:
                        shutil.unpack_archive(
                            arc_path + separator + ARCHIVES[0] + separator + i, arc_path + separator + ARCHIVES[0] + separator + i.replace("." + getExtension(i), ""))
                        os.remove(arc_path + separator +
                                ARCHIVES[0] + separator + i)
                    except shutil.ReadError:
                        os.remove(arc_path + separator +
                                ARCHIVES[0] + separator + i)


    PATH = path

    IMAGES = ("images", "jpeg", "png", "jpg", "svg")
    VIDEO = ("video", "avi", "mp4", "mov", "mkv")
    DOCUMENTS = ("documents", "doc", "docx", "txt", "pdf", "xlsx", "pptx")
    AUDIO = ("audio", "mp3", "ogg", "wav", "amr")
    ARCHIVES = ("archives", "zip", "gz", "tar")
    OTHERS = ("others")

    LIST_OF_TYPES = (IMAGES, VIDEO, DOCUMENTS, AUDIO, ARCHIVES)

    LIST_OF_DIRS = (IMAGES[0], VIDEO[0], DOCUMENTS[0],
                    AUDIO[0], ARCHIVES[0], OTHERS)

    TRANS = {}
    UKRAINIAN_SYMBOLS = 'абвгдеєжзиіїйклмнопрстуфхцчшщьюя'
    TRANSLATION = ("a", "b", "v", "g", "d", "e", "je", "zh", "z", "y", "i", "ji", "j", "k", "l", "m", "n", "o", "p", "r", "s", "t", "u",
                "f", "h", "ts", "ch", "sh", "sch", "", "ju", "ja")

    for key, value in zip(UKRAINIAN_SYMBOLS, TRANSLATION):
        TRANS[ord(key)] = value
        TRANS[ord(key.upper())] = value.upper()

    if sys.platform in ("linux", "darwin"):
        separator = "/"
    elif sys.platform in ("win32", "cygwin"):
        separator = '\\'

    list_of_use_extensions, list_other_extensions = walkSortDir(PATH)

    removeSortedDir(PATH)

    unpackSortedArchives(PATH)

    for sort_dir in os.listdir(PATH):
        if os.path.isdir(PATH + separator + sort_dir):
            if sort_dir != ARCHIVES[0]:
                print(
                    f"\nThese files have been moved to {PATH + separator + sort_dir}")
            else:
                print(
                    f"\nThese archives have been moved and unpacked to {PATH + separator + sort_dir}")
            for file_name in os.listdir(PATH + separator + sort_dir):
                print(file_name)
    if len(list_of_use_extensions) > 0:
        print(
            f"\nIidentified file types")
        for type in list_of_use_extensions:
            print(type)

    if len(list_other_extensions) > 0:
        print(
            f"\nUnidentified file types")
        for type in list_other_extensions:
            print(type)



from classes.field import Field
from classes.name import Name
from classes.birthday import Birthday
from classes.phone import Phone
from classes.email import Email
from classes.address import Address
from classes.record import Record
from classes.addressbook import AddressBook

from classes.note import Note
from classes.notes import Notes
from classes.functions import make_menu

from sort import sort
from terminal_bot_records_notes import

from classes.settings import filename, PAG, notes_filename


__autor__ = 'Avtarso'
__version__ = '0.0.1'
__email__ = 't0676352927@gmail.com'



from setuptools import setup, find_packages

setup(
    name='terminal_bot_records_notes',
    version='0.0.1',
    packages=find_packages(),
    license='MIT License',
    entry_points={
        'console_scripts': [
            'terminal_bot_records_notes=main:main'],
    },
    url='https://github.com/avtarso/python_core_21_team_11_project/tree/main',
    author='Avtarso',
    author_email='t0676352927@gmail.com',
    description='Command line bot personal assistant',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],

) 
